#!/usr/bin/env python
# coding: utf-8
from __future__ import print_function

import logging
import time

from selenium import webdriver
from selenium.common import exceptions as SeleniumExceptions
from selenium.webdriver.chrome.options import Options as ChromeOptions

logging.basicConfig(
	level = logging.INFO,  # switch to DEBUG for some selenium status stuff
	format = '\033[36m%(asctime)s \033[33m%(levelname)5s \033[0m%(message)s'
)

URLS = [
	'https://ocv.me/doc/selenium/res/redirect.html#a',
	'https://ocv.me/doc/selenium/res/redirect.html#b',
	'https://ocv.me/doc/selenium/res/redirect.html#c'
]


def main():
	logging.info('starting chrome')
	
	opts = ChromeOptions()
	opts.add_argument('--headless')
	opts.add_argument('--disable-gpu')
	
	# this defines how browser.get(url) will behave:
	#   none:   only wait for the html to download
	#   eager:  wait until the html has been parsed (firefox only)
	#   normal: wait until everything has been parsed (default)
	caps = webdriver.common.desired_capabilities.DesiredCapabilities.CHROME
	caps["pageLoadStrategy"] = "none"
	
	browser = webdriver.Chrome(desired_capabilities=caps, chrome_options=opts)
	browser.set_page_load_timeout(10)  # seconds

	for url in URLS:
		logging.info('loading [{0}]'.format(url))
		
		try:
			browser.get(url)
		except SeleniumExceptions.TimeoutException:
			logging.warn('timeout yolo')
		
		# wait until link does not contain "redirect.html#",
		# alternatively you could wait until a particular element shows up:
		# https://stackoverflow.com/questions/44503576/selenium-python-how-to-stop-page-loading-when-certain-element-gets-loaded
		start_time = time.time()
		while 'redirect.html#' in str(browser.current_url):
			time.sleep(0.1)
			time_spent = time.time() - start_time
			if time_spent > 10:
				logging.warn('this is taking too long')
				break
		
		# serves no actual purpose aside from usually making `browser.title` work in this particular example (you don't care about the title anyways so this is purely cosmetic)
		time.sleep(1)
		
		logging.info('* title [{0}]'.format(browser.title))
		logging.info('* url   [{0}]\n'.format(browser.current_url))
		
		# uncomment to see more of what the browser object can do
		#help(browser)

	logging.info('terminating chrome')
	browser.quit()
	
	logging.info('bye')


if __name__ == '__main__':
	main()
